@@ -279,19 +279,19 @@ main (int argc, char *argv[])
     tally_init ( &StatMem->ip_types, disabled,
 	StatMem->ip_protocol_count, 
 	-1, (int	*)0,
-	SN_MAX_IP_PORT+1, (char *)0,
+	SN_MAX_IP_PORT, (char *)0,
 	(unsigned int *)0, (unsigned int *)0, 0,
 	0, 0, (char *)0);
     tally_init ( &StatMem->tcp_port, disabled,
 	StatMem->tcp_port_ctr, 
 	-1, (int	*)0,
-	SN_MAX_TCP_PORTS+1, (char *)0,
+	SN_MAX_TCP_PORTS, (char *)0,
 	(unsigned int *)0, (unsigned int *)0, 0,
 	0, 0, (char *)0);
     tally_init ( &StatMem->udp_port, disabled,
 	StatMem->udp_port_ctr,
 	-1, (int	*)0,
-	SN_MAX_UDP_PORTS+1, (char *)0,
+	SN_MAX_UDP_PORTS, (char *)0,
 	(unsigned int *)0, (unsigned int *)0, 0,
 	0, 0, (char *)0);
     tally_init ( &StatMem->sap_types, disabled,
